<ul class="pagination">
    <li ng-repeat="n in [0, 1, 2, 3]" class="page-item">
        <a class="page-link" ng-click="sendForm(n)"
           ng-style="{'background-color': computeColor(n),
           'text-decoration': (n==value) ? 'underline' : ''}">{{ n }}</a></li>
</ul>